# Generated by Django 3.2.11 on 2022-03-04 01:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0030_auto_20220128_1719'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='ogtt2_base_datetime',
            field=models.DateTimeField(blank=True, help_text='(glucose solution given)', null=True, verbose_name='<u>Time</u> oral glucose solution was given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='ogtt2_datetime',
            field=models.DateTimeField(blank=True, help_text='(2 hours after glucose solution given)', null=True, verbose_name='<u>Time</u> blood glucose measured 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='ogtt2_quantifier',
            field=models.CharField(choices=[('=', '='), ('>', '>'), ('>=', '>='), ('<', '<'), ('<=', '<=')], default='=', max_length=10),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='ogtt2_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)')], max_length=15, null=True, verbose_name='Units (Blood glucose 2hrs after...)'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartone',
            name='ogtt2_value',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='A `HIGH` reading may be entered as 9999.99', max_digits=8, null=True, verbose_name='Blood glucose <u>level</u> 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='ogtt2_base_datetime',
            field=models.DateTimeField(blank=True, help_text='(glucose solution given)', null=True, verbose_name='<u>Time</u> oral glucose solution was given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='ogtt2_datetime',
            field=models.DateTimeField(blank=True, help_text='(2 hours after glucose solution given)', null=True, verbose_name='<u>Time</u> blood glucose measured 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='ogtt2_quantifier',
            field=models.CharField(choices=[('=', '='), ('>', '>'), ('>=', '>='), ('<', '<'), ('<=', '<=')], default='=', max_length=10),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='ogtt2_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)')], max_length=15, null=True, verbose_name='Units (Blood glucose 2hrs after...)'),
        ),
        migrations.AddField(
            model_name='historicalscreeningpartthree',
            name='ogtt2_value',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='A `HIGH` reading may be entered as 9999.99', max_digits=8, null=True, verbose_name='Blood glucose <u>level</u> 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='ogtt2_base_datetime',
            field=models.DateTimeField(blank=True, help_text='(glucose solution given)', null=True, verbose_name='<u>Time</u> oral glucose solution was given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='ogtt2_datetime',
            field=models.DateTimeField(blank=True, help_text='(2 hours after glucose solution given)', null=True, verbose_name='<u>Time</u> blood glucose measured 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='ogtt2_quantifier',
            field=models.CharField(choices=[('=', '='), ('>', '>'), ('>=', '>='), ('<', '<'), ('<=', '<=')], default='=', max_length=10),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='ogtt2_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)')], max_length=15, null=True, verbose_name='Units (Blood glucose 2hrs after...)'),
        ),
        migrations.AddField(
            model_name='historicalscreeningparttwo',
            name='ogtt2_value',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='A `HIGH` reading may be entered as 9999.99', max_digits=8, null=True, verbose_name='Blood glucose <u>level</u> 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='ogtt2_base_datetime',
            field=models.DateTimeField(blank=True, help_text='(glucose solution given)', null=True, verbose_name='<u>Time</u> oral glucose solution was given'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='ogtt2_datetime',
            field=models.DateTimeField(blank=True, help_text='(2 hours after glucose solution given)', null=True, verbose_name='<u>Time</u> blood glucose measured 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='ogtt2_quantifier',
            field=models.CharField(choices=[('=', '='), ('>', '>'), ('>=', '>='), ('<', '<'), ('<=', '<=')], default='=', max_length=10),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='ogtt2_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)')], max_length=15, null=True, verbose_name='Units (Blood glucose 2hrs after...)'),
        ),
        migrations.AddField(
            model_name='historicalsubjectscreening',
            name='ogtt2_value',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='A `HIGH` reading may be entered as 9999.99', max_digits=8, null=True, verbose_name='Blood glucose <u>level</u> 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='ogtt2_base_datetime',
            field=models.DateTimeField(blank=True, help_text='(glucose solution given)', null=True, verbose_name='<u>Time</u> oral glucose solution was given'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='ogtt2_datetime',
            field=models.DateTimeField(blank=True, help_text='(2 hours after glucose solution given)', null=True, verbose_name='<u>Time</u> blood glucose measured 2-hours after oral glucose solution given'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='ogtt2_quantifier',
            field=models.CharField(choices=[('=', '='), ('>', '>'), ('>=', '>='), ('<', '<'), ('<=', '<=')], default='=', max_length=10),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='ogtt2_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)')], max_length=15, null=True, verbose_name='Units (Blood glucose 2hrs after...)'),
        ),
        migrations.AddField(
            model_name='subjectscreening',
            name='ogtt2_value',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='A `HIGH` reading may be entered as 9999.99', max_digits=8, null=True, verbose_name='Blood glucose <u>level</u> 2-hours after oral glucose solution given'),
        ),
    ]
