# Generated by Django 2.2.7 on 2020-01-20 16:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0014_auto_20200120_1622"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="bloodresultslipid",
            options={
                "verbose_name": "Blood Result: Lipids",
                "verbose_name_plural": "Blood Results: Lipids",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalbloodresultslipid",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Blood Result: Lipids",
            },
        ),
    ]
