# Generated by Django 3.2.4 on 2021-08-10 05:57

import edc_model.models.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0077_auto_20210809_2323"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="arv_regimen_start_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[
                    edc_model.models.validators.date.date_not_future,
                    edc_model.models.validators.date.date_is_not_now,
                ],
                verbose_name="Start date",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="arv_regimen_start_date",
            field=models.DateField(
                blank=True,
                null=True,
                validators=[
                    edc_model.models.validators.date.date_not_future,
                    edc_model.models.validators.date.date_is_not_now,
                ],
                verbose_name="Start date",
            ),
        ),
    ]
