# Generated by Django 2.2.6 on 2019-11-01 21:33

import edc_model_fields.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("meta_ae", "0002_auto_20191024_1000")]

    operations = [
        migrations.AlterField(
            model_name="aeinitial",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="other_informant_relationship",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="ae_classification_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="other_informant_relationship",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]
