# Generated by Django 3.2.4 on 2021-06-28 18:05

import django.contrib.sites.managers
import django.core.validators
import django.db.models.deletion
import edc_visit_tracking.managers
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0052_auto_20210624_0225"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="bloodresultsfbc",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultsglu",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultshba1c",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslft",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslipid",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultsrft",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="fbc_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="haemoglobin",
            new_name="haemoglobin_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="hct",
            new_name="hct_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="platelets",
            new_name="platelets_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="rbc",
            new_name="rbc_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="wbc",
            new_name="wbc_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_abnormal",
            new_name="gluc_abnormal",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_quantifier",
            new_name="gluc_quantifier",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_reportable",
            new_name="gluc_reportable",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_units",
            new_name="gluc_units",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose",
            new_name="gluc_value",
        ),
        migrations.RenameField(
            model_name="bloodresultshba1c",
            old_name="hba1c_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="albumin",
            new_name="albumin_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="alp",
            new_name="alp_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="alt",
            new_name="alt_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="lft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="ast",
            new_name="ast_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="ggt",
            new_name="ggt_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="lipid_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="rft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="egfr",
            new_name="egfr_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="urea",
            new_name="urea_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="uric_acid",
            new_name="uric_acid_value",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="fbc_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="haemoglobin",
            new_name="haemoglobin_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="hct",
            new_name="hct_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="platelets",
            new_name="platelets_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="rbc",
            new_name="rbc_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="fbc_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsfbc",
            old_name="wbc",
            new_name="wbc_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_abnormal",
            new_name="gluc_abnormal",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_quantifier",
            new_name="gluc_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_reportable",
            new_name="gluc_reportable",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_units",
            new_name="gluc_units",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose",
            new_name="gluc_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsglu",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultshba1c",
            old_name="hba1c_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultshba1c",
            old_name="hba1c_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="albumin",
            new_name="albumin_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="alp",
            new_name="alp_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="alt",
            new_name="alt_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="lft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="ast",
            new_name="ast_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="ggt",
            new_name="ggt_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="lft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="lipid_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="lipid_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="rft_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="egfr",
            new_name="egfr_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="rft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="urea",
            new_name="urea_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="uric_acid",
            new_name="uric_acid_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr_datetime",
            new_name="ogtt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr_quantifier",
            new_name="ogtt_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr_units",
            new_name="ogtt_units",
        ),
        #
        #
        #
        migrations.RenameField(
            model_name="bloodresultsfbc",
            old_name="fbc_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultsglu",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultshba1c",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="bloodresultshba1c",
            old_name="hba1c_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="amylase",
            new_name="amylase_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslft",
            old_name="lft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="lipid_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="bloodresultsrft",
            old_name="rft_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultshba1c",
            old_name="hba1c",
            new_name="hba1c_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslft",
            old_name="amylase",
            new_name="amylase_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultsrft",
            old_name="creatinine",
            new_name="creatinine_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose",
            new_name="ifg_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose_datetime",
            new_name="ifg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose_quantifier",
            new_name="ifg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="fasting_glucose_units",
            new_name="ifg_units",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="ogtt_two_hr",
            new_name="ogtt_value",
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="hba1c_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="hba1c_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL")],
                max_length=25,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="urea_units",
            field=models.CharField(
                blank=True,
                choices=[("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL")],
                max_length=25,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="urea_units",
            field=models.CharField(
                blank=True,
                choices=[("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="hba1c_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=8,
                null=True,
                verbose_name="Blood Glucose",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="amylase_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=6, null=True
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="requisition",
            field=models.ForeignKey(
                blank=True,
                help_text="Start typing the requisition identifier or select one from this visit",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="meta_subject.subjectrequisition",
                verbose_name="Requisition",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                max_digits=8,
                null=True,
                verbose_name="Blood Glucose",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="amylase_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="creatinine_value",
            field=models.DecimalField(
                blank=True, decimal_places=2, max_digits=6, null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> IFG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="IFG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ogtt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="Blood glucose <u>level</u> 2-hours after oral glucose solution given",
            ),
        ),
    ]
