# Generated by Django 3.2.11 on 2022-04-07 14:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('meta_screening', '0042_auto_20220403_1402'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='repeat_fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='As reported by patient', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartone',
            name='repeat_glucose_performed',
            field=models.CharField(choices=[('PENDING', 'Pending (scheduled for 3 days from first)'), ('Yes', 'Yes'), ('N/A', 'Not applicable')], default='N/A', help_text='Select YES when you are ready to enter the repeat results', max_length=15, verbose_name='Were the glucose measurements repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='repeat_fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='As reported by patient', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningpartthree',
            name='repeat_glucose_performed',
            field=models.CharField(choices=[('PENDING', 'Pending (scheduled for 3 days from first)'), ('Yes', 'Yes'), ('N/A', 'Not applicable')], default='N/A', help_text='Select YES when you are ready to enter the repeat results', max_length=15, verbose_name='Were the glucose measurements repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='repeat_fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='As reported by patient', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalscreeningparttwo',
            name='repeat_glucose_performed',
            field=models.CharField(choices=[('PENDING', 'Pending (scheduled for 3 days from first)'), ('Yes', 'Yes'), ('N/A', 'Not applicable')], default='N/A', help_text='Select YES when you are ready to enter the repeat results', max_length=15, verbose_name='Were the glucose measurements repeated?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='repeat_fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='As reported by patient', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='repeat_glucose_performed',
            field=models.CharField(choices=[('PENDING', 'Pending (scheduled for 3 days from first)'), ('Yes', 'Yes'), ('N/A', 'Not applicable')], default='N/A', help_text='Select YES when you are ready to enter the repeat results', max_length=15, verbose_name='Were the glucose measurements repeated?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='repeat_fasting',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='As reported by patient', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='repeat_glucose_performed',
            field=models.CharField(choices=[('PENDING', 'Pending (scheduled for 3 days from first)'), ('Yes', 'Yes'), ('N/A', 'Not applicable')], default='N/A', help_text='Select YES when you are ready to enter the repeat results', max_length=15, verbose_name='Were the glucose measurements repeated?'),
        ),
    ]
