DAY1 = "1000"
DELIVERY = "2000"
MONTH1 = "1010"
MONTH12 = "1120"
MONTH15 = "1150"
MONTH18 = "1180"
MONTH21 = "1210"
MONTH24 = "1240"
MONTH27 = "1270"
MONTH3 = "1030"
MONTH30 = "1300"
MONTH33 = "1330"
MONTH36 = "1360"
MONTH6 = "1060"
MONTH9 = "1090"
POSTNATAL = "3000"
SCHEDULE = "schedule"
SCHEDULE_POSTNATAL = "schedule_postnatal"
SCHEDULE_PREGNANCY = "schedule_pregnancy"
VISIT_SCHEDULE = "visit_schedule"
WEEK2 = "1005"
