ALL_OF_THE_TIME = "all_of_the_time"
APPT = "appt"
APPT_OTHER = "other_routine_appt"
DELIVERY_ACTION = "delivery_action"
FOLLOWUP_EXAMINATION_ACTION = "followup-examination-ae"
GOOD_BIT_OF_THE_TIME = "good_bit_of_the_time"
LITTLE_OF_THE_TIME = "little_of_the_time"
LIVE_AT_TERM = "live_at_term"
LIVE_PRETERM = "live_preterm"
LOW_EGFR_ACTION = "low-egfr"
MISSED_VISIT_ACTION = "missed_visit_action"
MOST_OF_THE_TIME = "most_of_the_time"
NONE_OF_THE_TIME = "none_of_the_time"
NO_COMPLICATIONS = "no_complications"
SOME_OF_THE_TIME = "some_of_the_time"
URINE_PREGNANCY_ACTION = "urine_pregnancy_action"
