# Generated by Django 3.2.4 on 2021-08-04 01:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0069_auto_20210801_2021"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucose",
            name="ifg_units",
            field=models.CharField(
                choices=[
                    ("mg/dL", "mg/dL"),
                    ("mmol/L", "mmol/L (millimoles/L)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ogtt_units",
            field=models.CharField(
                choices=[
                    ("mg/dL", "mg/dL"),
                    ("mmol/L", "mmol/L (millimoles/L)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Units (Blood glucose 2hrs after...)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_units",
            field=models.CharField(
                choices=[
                    ("mg/dL", "mg/dL"),
                    ("mmol/L", "mmol/L (millimoles/L)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="IFG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ogtt_units",
            field=models.CharField(
                choices=[
                    ("mg/dL", "mg/dL"),
                    ("mmol/L", "mmol/L (millimoles/L)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Units (Blood glucose 2hrs after...)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="on_hypertension_treatment",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                verbose_name="Is the patient on treatment for hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="on_hypertension_treatment",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                verbose_name="Is the patient on treatment for hypertension?",
            ),
        ),
    ]
