# Generated by Django 3.2.4 on 2021-08-09 14:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0074_auto_20210809_1744"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="on_hypertension_treatment",
            new_name="on_htn_treatment",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="on_hypertension_treatment",
            new_name="on_htn_treatment",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="diabetes_in_family",
            new_name="dm_in_family",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="other_diabetes_symptoms",
            new_name="other_dm_symptoms",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="other_hypertension_treatment",
            new_name="other_htn_treatment",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="diabetes_in_family",
            new_name="dm_in_family",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="diabetes_symptoms",
            new_name="dm_symptoms",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="hypertension_treatment",
            new_name="htn_treatment",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="other_diabetes_symptoms",
            new_name="other_dm_symptoms",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="other_hypertension_treatment",
            new_name="other_htn_treatment",
        ),
    ]
