# Generated by Django 2.2.11 on 2020-03-25 06:01

import django.core.validators
import edc_visit_tracking.managers
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0016_auto_20200123_1508"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="bloodresultsfbc",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultshba1c",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslft",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultslipid",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="bloodresultsrft",
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form.",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
    ]
