# Generated by Django 3.2.6 on 2021-08-23 20:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0026_auto_20210712_0433"),
    ]

    operations = []
