# Generated by Django 3.2.6 on 2021-09-09 23:38

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_action_item", "0028_auto_20210203_0706"),
        ("edc_protocol_violation", "0001_initial"),
        ("meta_prn", "0007_auto_20210721_0335"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="requestor",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="reviewer",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="site",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="requestor",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="site",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="reviewer",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="site",
        ),
        migrations.DeleteModel(
            name="UnblindingRequestorUser",
        ),
        migrations.DeleteModel(
            name="UnblindingReviewerUser",
        ),
        migrations.DeleteModel(
            name="HistoricalUnblindingRequest",
        ),
        migrations.DeleteModel(
            name="HistoricalUnblindingReview",
        ),
        migrations.DeleteModel(
            name="UnblindingRequest",
        ),
        migrations.DeleteModel(
            name="UnblindingReview",
        ),
    ]
